<?php
/* Template Name: Custom Search Results */
/* The template for displaying the custom search results page.
 *
 * @package WordPress
 * @subpackage BookYourTravel
 * @since Book Your Travel 1.0
 */
 
global $current_url, $bookyourtravel_theme_globals, $current_user, $frontend_submit, $bookyourtravel_review_helper, $bookyourtravel_accommodation_helper, $bookyourtravel_car_rental_helper, $bookyourtravel_cruise_helper, $bookyourtravel_tour_helper, $item_class, $date_from, $date_to;

get_header();  
BookYourTravel_Theme_Utils::breadcrumbs();
get_sidebar('under-header');

$enable_reviews = $bookyourtravel_theme_globals->enable_reviews();
$enable_accommodations = $bookyourtravel_theme_globals->enable_accommodations();
$current_user = wp_get_current_user();
$user_info = get_userdata($current_user->ID);
$price_decimal_places = $bookyourtravel_theme_globals->get_price_decimal_places();
$default_currency_symbol = $bookyourtravel_theme_globals->get_default_currency_symbol();
$show_currency_symbol_after = $bookyourtravel_theme_globals->show_currency_symbol_after();

$default_results_view = $bookyourtravel_theme_globals->get_search_results_default_view();
$custom_search_results_page = $bookyourtravel_theme_globals->get_custom_search_results_page_url();

$request_car_types = BookYourTravel_Theme_Utils::retrieve_array_of_values_from_query_string('car_types', true);
$request_car_rental_tags = BookYourTravel_Theme_Utils::retrieve_array_of_values_from_query_string('car_rental_tags', true);
$request_tour_types = BookYourTravel_Theme_Utils::retrieve_array_of_values_from_query_string('tour_types', true);
$request_tour_tags= BookYourTravel_Theme_Utils::retrieve_array_of_values_from_query_string('tour_tags', true);
$request_cruise_types = BookYourTravel_Theme_Utils::retrieve_array_of_values_from_query_string('cruise_types', true);
$request_cruise_tags = BookYourTravel_Theme_Utils::retrieve_array_of_values_from_query_string('cruise_tags', true);
$request_accommodation_types = BookYourTravel_Theme_Utils::retrieve_array_of_values_from_query_string('accommodation_types', true);
$request_accommodation_tags = BookYourTravel_Theme_Utils::retrieve_array_of_values_from_query_string('accommodation_tags', true);
$request_cabin_types = BookYourTravel_Theme_Utils::retrieve_array_of_values_from_query_string('cabin_types', true);
$request_prices = BookYourTravel_Theme_Utils::retrieve_array_of_values_from_query_string('price', true);

$search_term = isset($_GET['term']) ? sanitize_text_field($_GET['term']) : '';
$location_id = isset($_GET['l']) ? intval(wp_kses($_GET['l'], array())) : 0; 
$age = isset($_GET['age']) ? intval(wp_kses($_GET['age'], array())) : 0; 
$stars = isset($_GET['stars']) ? intval(wp_kses($_GET['stars'], array())) : 0; 
$rating = isset($_GET['rating']) ? intval(wp_kses($_GET['rating'], array())) : 0; 
$guests = isset($_GET['guests']) ? intval(wp_kses($_GET['guests'], array())) : 0; 
$cabins = isset($_GET['cabins']) ? intval(wp_kses($_GET['cabins'], array())) : 0; 
$rooms = isset($_GET['rooms']) ? intval(wp_kses($_GET['rooms'], array())) : 0; 
$what = isset($_GET['what']) ? intval(wp_kses($_GET['what'], array())) : 1; 

$sort_by = isset($_GET['sb']) ? intval(wp_kses($_GET['sb'], array())) : 1; 
$sort_order = isset($_GET['so']) ? intval(wp_kses($_GET['so'], array())) : 1;

$date_from = isset($_GET['from']) && !empty($_GET['from'])  ? date('Y-m-d', strtotime(sanitize_text_field($_GET['from']))) : null;
$date_to = isset($_GET['to']) && !empty($_GET['to']) ? date('Y-m-d', strtotime(sanitize_text_field($_GET['to']))) : null;

$paged = (get_query_var('paged')) ? get_query_var('paged') : 1;
$posts_per_page = $bookyourtravel_theme_globals->get_search_results_posts_per_page();

$search_args = array();

$search_args['date_from'] = $date_from;
$search_args['date_to'] = $date_to;
$search_args['keyword'] = $search_term;
$search_args['prices'] = $request_prices;

$search_args['price_range_bottom'] = $bookyourtravel_theme_globals->get_price_range_bottom();
$search_args['price_range_increment'] = $bookyourtravel_theme_globals->get_price_range_increment();
$search_args['price_range_count'] = $bookyourtravel_theme_globals->get_price_range_count();
$search_args['search_only_available'] = $bookyourtravel_theme_globals->search_only_available_properties();

if ($what == 1) {

	$sort_order = $sort_order == '1' ? 'ASC' : 'DESC';
	if (isset($sort_by)) {
		switch ($sort_by) {
			case '1' : $sort_by = 'min_price';break;// price
			case '2' : $sort_by = 'star_count';break;// star count
			case '3' : $sort_by = 'review_score';break;// star count
			default : $sort_by = 'accommodations.post_title';break;
		}
	} else {
		$sort_by = 'accommodations.post_title';
	}

	$search_args['rating'] = $rating;
	$search_args['rooms'] = $rooms;
	$search_args['stars'] = $stars;
	
	$results = $bookyourtravel_accommodation_helper->list_accommodations ( $paged, $posts_per_page, $sort_by, $sort_order, $location_id, $request_accommodation_types, array(), $search_args, false);
	$current_url = $custom_search_results_page . '?from=' . urlencode($date_from) . '&to=' . urlencode($date_to) . '&term=' . $search_term . '&what=' . $what;

} else if ($what == 2) {

	$search_args['age'] = $age;
	$sort_by = $sort_by == '1' ? 'price' : 'car_rentals.post_title';
	$sort_order = $sort_order == '1' ? 'ASC' : 'DESC';
	
	$results = $bookyourtravel_car_rental_helper->list_car_rentals($paged, $posts_per_page, $sort_by, $sort_order, $location_id, $request_car_types, array(), $search_args);
	$current_url = $custom_search_results_page . '?from=' . urlencode($date_from) . '&to=' . urlencode($date_to) . '&term=' . $search_term . '&what=' . $what;

} else if ($what == 3) {

	$search_args['guests'] = $guests;
	$sort_by = $sort_by == '1' ? 'tours.ID' : 'tours.post_title';
	$sort_order = $sort_order == '1' ? 'ASC' : 'DESC';

	$results = $bookyourtravel_tour_helper->list_tours($paged, $posts_per_page, $sort_by, $sort_order, $location_id,$request_tour_types, array(), $search_args);
	$current_url = $custom_search_results_page . '?from=' . urlencode($date_from) . '&term=' . $search_term . '&what=' . $what;
	
} else if ($what == 4) {

	$search_args['guests'] = $guests;
	$search_args['cabins'] = $cabins;
	$sort_by = $sort_by == '1' ? 'cruises.ID' : 'cruises.post_title';
	$sort_order = $sort_order == '1' ? 'ASC' : 'DESC';

	$results = $bookyourtravel_cruise_helper->list_cruises($paged, $posts_per_page, $sort_by, $sort_order, $location_id, $request_cruise_types, array(), $search_args);
	$current_url = $custom_search_results_page . '?from=' . urlencode($date_from) . '&what=' . $what;
}

$page_id = $post->ID;
$page_custom_fields = get_post_custom( $page_id);

$page_sidebar_positioning = null;
if (isset($page_custom_fields['page_sidebar_positioning'])) {
	$page_sidebar_positioning = $page_custom_fields['page_sidebar_positioning'][0];
	$page_sidebar_positioning = empty($page_sidebar_positioning) ? '' : $page_sidebar_positioning;
}

$section_class = 'full-width';
$item_class = 'one-fourth';
if ($page_sidebar_positioning == 'both') {
	$section_class = 'one-half';
	$item_class = 'one-half';
} else if ($page_sidebar_positioning == 'left' || $page_sidebar_positioning == 'right') {
	$section_class = 'three-fourth';
	$item_class = 'one-third';
}
?>
<div class="row">
	<?php
	if ($page_sidebar_positioning == 'both' || $page_sidebar_positioning == 'left')
		get_sidebar('left');
	?>
	<script>
		window.itemClass = <?php echo json_encode($item_class); ?>;
	</script>
	<section class="<?php echo esc_attr($section_class); ?>">
		<div class="sort-by">
			<h3><?php esc_html_e('Sort by', 'bookyourtravel'); ?></h3>
			<ul class="sort">
				<li><?php esc_html_e('Price', 'bookyourtravel'); ?> <a href="<?php echo esc_url($current_url) . '&sb=1&so=1'; ?>" title="<?php esc_attr_e('ascending', 'bookyourtravel'); ?>" class="ascending"><?php esc_html_e('ascending', 'bookyourtravel'); ?></a><a href="<?php echo esc_url($current_url) . '&sb=1&so=2'; ?>" title="<?php esc_attr_e('descending', 'bookyourtravel'); ?>" class="descending"><?php esc_html_e('descending', 'bookyourtravel'); ?></a></li>
				<?php if ($what == 1) { ?>
				<li><?php esc_html_e('Stars', 'bookyourtravel'); ?> <a href="<?php echo esc_url($current_url) . '&sb=2&so=1'; ?>" title="<?php esc_attr_e('ascending', 'bookyourtravel'); ?>" class="ascending"><?php esc_html_e('ascending', 'bookyourtravel'); ?></a><a href="<?php echo esc_url($current_url) . '&sb=2&so=2'; ?>" title="<?php esc_attr_e('descending', 'bookyourtravel'); ?>" class="descending"><?php esc_html_e('descending', 'bookyourtravel'); ?></a></li>
				<li><?php esc_html_e('Rating', 'bookyourtravel'); ?> <a href="<?php echo esc_url($current_url) . '&sb=3&so=1'; ?>" title="<?php esc_attr_e('ascending', 'bookyourtravel'); ?>" class="ascending"><?php esc_html_e('ascending', 'bookyourtravel'); ?></a><a href="<?php echo esc_url($current_url) . '&sb=3&so=2'; ?>" title="<?php esc_attr_e('descending', 'bookyourtravel'); ?>" class="descending"><?php esc_html_e('descending', 'bookyourtravel'); ?></a></li>
				<?php } ?>
			</ul>
			
			<ul class="view-type">
				<script>
					window.defaultResultsView = <?php echo json_encode($default_results_view); ?>;
				</script>
				<li class="grid-view <?php echo ($default_results_view === 0) ? 'active' : ''; ?>"><a href="#" title="grid view"><?php esc_html_e('grid view', 'bookyourtravel'); ?></a></li>
				<li class="list-view <?php echo ($default_results_view === 1) ? 'active' : ''; ?>"><a href="#" title="list view"><?php esc_html_e('list view', 'bookyourtravel'); ?></a></li>
			</ul>
		</div>
	
		<div class="deals">
			<!--deal-->
			<?php 
			if (count($results) > 0 && $results['total'] > 0) { ?>
				<div class="row">
				<?php
				foreach ($results['results'] as $result) { 
					global $post;
					$post = $result;
					setup_postdata( $post ); 
					if ($what == 1) {
						get_template_part('includes/parts/accommodation', 'item');
					} elseif ($what == 2) {
						get_template_part('includes/parts/car_rental', 'item');
					} elseif ($what == 3) {
						get_template_part('includes/parts/tour', 'item');
					} elseif ($what == 4) {
						get_template_part('includes/parts/cruise', 'item');
					}
				} ?>
				</div>
				<nav class="page-navigation bottom-nav">
					<!--back up button-->
					<a href="#" class="scroll-to-top" title="<?php esc_attr_e('Back up', 'bookyourtravel'); ?>"><?php esc_html_e('Back up', 'bookyourtravel'); ?></a> 
					<!--//back up button-->
					<div class="pager">
					<?php 
						$total_results = $results['total'];
						BookYourTravel_Theme_Utils::display_pager( ceil($total_results/$posts_per_page) );
					?>
					</div>
				</nav>
			<?php } else { ?>
				<p><?php esc_html_e('Unfortunately no results match your search criteria. Please try searching for something else.', 'bookyourtravel'); ?></p>
			<?php } ?>
		</div>
	</section>
	<?php 
	wp_reset_postdata();
	wp_reset_query();

	if ($page_sidebar_positioning == 'both' || $page_sidebar_positioning == 'right')
		get_sidebar('right');
	?>
</div>
<?php	
get_footer();