<?php

require_once BookYourTravel_Theme_Utils::get_file_path('/includes/post_types/class-review-helper.php');
require_once BookYourTravel_Theme_Utils::get_file_path('/includes/post_types/class-location-helper.php');
require_once BookYourTravel_Theme_Utils::get_file_path('/includes/post_types/class-facility-helper.php');
require_once BookYourTravel_Theme_Utils::get_file_path('/includes/post_types/class-room-type-helper.php');
require_once BookYourTravel_Theme_Utils::get_file_path('/includes/post_types/class-accommodation-helper.php');
require_once BookYourTravel_Theme_Utils::get_file_path('/includes/post_types/class-tour-helper.php');
require_once BookYourTravel_Theme_Utils::get_file_path('/includes/post_types/class-cabin-type-helper.php');
require_once BookYourTravel_Theme_Utils::get_file_path('/includes/post_types/class-cruise-helper.php');
require_once BookYourTravel_Theme_Utils::get_file_path('/includes/post_types/class-car-rental-helper.php');
require_once BookYourTravel_Theme_Utils::get_file_path('/includes/post_types/class-post-helper.php');
require_once BookYourTravel_Theme_Utils::get_file_path('/includes/post_types/class-extra-item-helper.php');

class BookYourTravel_Theme_Post_Types extends BookYourTravel_BaseSingleton {

	private $user_account_custom_meta_fields;
	private $user_account_meta_box;
	private $user_content_list_custom_meta_fields;
	private $user_content_list_meta_box;

	private $enable_accommodations;
	private $enable_tours;
	private $enable_cruises;
	private $enable_car_rentals;

	protected function __construct() {
	
		global $bookyourtravel_theme_globals;
		
		$this->enable_accommodations = $bookyourtravel_theme_globals->enable_accommodations();
		$this->enable_tours = $bookyourtravel_theme_globals->enable_tours();
		$this->enable_cruises = $bookyourtravel_theme_globals->enable_cruises();
		$this->enable_car_rentals = $bookyourtravel_theme_globals->enable_car_rentals();

		$this->user_account_custom_meta_fields = array(
			array( // Post ID select box
				'label'	=> esc_html__('Is partner page?', 'bookyourtravel'), // <label>
				'desc'	=> esc_html__('If checked, will display partner (front end submit) pages and menus', 'bookyourtravel'), // description
				'id'	=> 'user_account_is_partner_page', // field id and name
				'type'	=> 'checkbox', // type of field
			)
		);

		$user_content_types = array();
		
		if ($this->enable_accommodations) {
			$user_content_types[] = array('value' => 'accommodation', 'label' => esc_html__('Accommodation', 'bookyourtravel'));
			$user_content_types[] = array('value' => 'vacancy', 'label' => esc_html__('Accommodation vacancy', 'bookyourtravel'));
			$user_content_types[] = array('value' => 'room_type', 'label' => esc_html__('Room type', 'bookyourtravel'));
		}
		
		if ($this->enable_tours) {
			$user_content_types[] = array('value' => 'tour', 'label' => esc_html__('Tour', 'bookyourtravel'));
			$user_content_types[] = array('value' => 'tour_schedule', 'label' => esc_html__('Tour schedule', 'bookyourtravel'));
		}
		
		if ($this->enable_cruises) {
			$user_content_types[] = array('value' => 'cruise', 'label' => esc_html__('Cruise', 'bookyourtravel'));
			$user_content_types[] = array('value' => 'cabin_type', 'label' => esc_html__('Cabin type', 'bookyourtravel'));
			$user_content_types[] = array('value' => 'cruise_schedule', 'label' => esc_html__('Cruise schedule', 'bookyourtravel'));
		}
		
		if ($this->enable_car_rentals) {
			$user_content_types[] = array('value' => 'car_rental', 'label' => esc_html__('Car rental', 'bookyourtravel'));
		}

		$this->user_content_list_custom_meta_fields = array(
			array( // Select box
				'label'	=> esc_html__('User content type', 'bookyourtravel'), // <label>
				// the description is created in the callback function with a link to Manage the taxonomy terms
				'id'	=> 'user_content_type', // field id and name, needs to be the exact name of the taxonomy
				'type'	=> 'select', // type of field
				'options' => $user_content_types
			),
		);
		
        // our parent class might
        // contain shared code in its constructor
        parent::__construct();
    }

    public function init() {
		add_action( 'init', array($this, 'initialize_post_types' ) );
    }
	
	function initialize_post_types() {
	
		do_action('bookyourtravel_initialize_post_types');
		
		if ($this->enable_accommodations) {	
		
			add_action( 'admin_init', array( $this, 'accommodation_admin_init' ) );
		}
	}
	
	function accommodation_admin_init() {
		
		$this->user_account_meta_box = new custom_add_meta_box( 'user_account_custom_meta_fields', esc_html__('Extra information', 'bookyourtravel'), $this->user_account_custom_meta_fields, 'page' );	
		remove_action( 'add_meta_boxes', array( $this->user_account_meta_box, 'add_box' ) );
		add_action('add_meta_boxes', array( $this, 'user_account_add_meta_boxes' ) );
		
		$this->user_content_list_meta_box = new custom_add_meta_box( 'user_content_list_custom_meta_fields', esc_html__('Extra information', 'bookyourtravel'), $this->user_content_list_custom_meta_fields, 'page' );	
		remove_action( 'add_meta_boxes', array( $this->user_content_list_meta_box, 'add_box' ) );
		add_action('add_meta_boxes', array( $this, 'user_content_list_add_meta_boxes' ) );

	}
	
	function user_account_add_meta_boxes() {
	
		global $post;
		$template_file = get_post_meta($post->ID,'_wp_page_template',true);
		if ($template_file == 'page-user-account.php') {
			add_meta_box( $this->user_account_meta_box->id, $this->user_account_meta_box->title, array( $this->user_account_meta_box, 'meta_box_callback' ), 'page', 'normal', 'high' );
		}
	}	
	
	function user_content_list_add_meta_boxes() {
	
		global $post;
		$template_file = get_post_meta($post->ID,'_wp_page_template',true);
		if ($template_file == 'page-user-content-list.php') {
			add_meta_box( $this->user_content_list_meta_box->id, $this->user_content_list_meta_box->title, array( $this->user_content_list_meta_box, 'meta_box_callback' ), 'page', 'normal', 'high' );
		}
	}	
}

// store the instance in a variable to be retrieved later and call init
$bookyourtravel_theme_post_types = BookYourTravel_Theme_Post_Types::get_instance();
$bookyourtravel_theme_post_types->init();