<?php
/*	Template Name: User Submit Content
 * The template for displaying submit forms for front-end content submission
 *
 * @package WordPress
 * @subpackage BookYourTravel
 * @since Book Your Travel 1.0
 */

global $bookyourtravel_theme_globals, $bookyourtravel_accommodation_helper, $bookyourtravel_review_helper, $current_user, $frontend_submit;

if ( !is_user_logged_in() || !$frontend_submit->user_has_correct_role()) {
	wp_redirect( home_url('/') );
	exit;
}

get_header();  
BookYourTravel_Theme_Utils::breadcrumbs();
get_sidebar('under-header');

$enable_reviews = $bookyourtravel_theme_globals->enable_reviews();
$enable_accommodations = $bookyourtravel_theme_globals->enable_accommodations();
$enable_tours = $bookyourtravel_theme_globals->enable_tours();
$enable_cruises = $bookyourtravel_theme_globals->enable_cruises();
$enable_car_rentals = $bookyourtravel_theme_globals->enable_car_rentals();

$current_user = wp_get_current_user();
$user_info = get_userdata($current_user->ID);
$price_decimal_places = $bookyourtravel_theme_globals->get_price_decimal_places();
$default_currency_symbol = $bookyourtravel_theme_globals->get_default_currency_symbol();
$show_currency_symbol_after = $bookyourtravel_theme_globals->show_currency_symbol_after();

$my_account_page_url = $bookyourtravel_theme_globals->get_my_account_page_url();
$submit_room_types_url = $bookyourtravel_theme_globals->get_submit_room_types_url();
$submit_accommodations_url = $bookyourtravel_theme_globals->get_submit_accommodations_url();
$submit_accommodation_vacancies_url = $bookyourtravel_theme_globals->get_submit_accommodation_vacancies_url();
$submit_tours_url = $bookyourtravel_theme_globals->get_submit_tours_url();
$submit_tour_schedules_url = $bookyourtravel_theme_globals->get_submit_tour_schedules_url();
$submit_tour_schedules_url_with_arg = $submit_tour_schedules_url;
$submit_tour_schedules_url_with_arg = add_query_arg( 'fesid', '', $submit_tour_schedules_url_with_arg);
$submit_cruises_url = $bookyourtravel_theme_globals->get_submit_cruises_url();
$submit_cabin_types_url = $bookyourtravel_theme_globals->get_submit_cabin_types_url();
$submit_cruise_schedules_url = $bookyourtravel_theme_globals->get_submit_cruise_schedules_url();
$submit_cruise_schedules_url_with_arg = $submit_cruise_schedules_url;
$submit_cruise_schedules_url_with_arg = add_query_arg( 'fesid', '', $submit_cruise_schedules_url_with_arg);
$submit_car_rentals_url = $bookyourtravel_theme_globals->get_submit_car_rentals_url();
$list_user_room_types_url = $bookyourtravel_theme_globals->get_list_user_room_types_url();
$list_user_accommodations_url = $bookyourtravel_theme_globals->get_list_user_accommodations_url();
$list_user_accommodation_vacancies_url = $bookyourtravel_theme_globals->get_list_user_accommodation_vacancies_url();
$list_user_tours_url = $bookyourtravel_theme_globals->get_list_user_tours_url();
$list_user_tour_schedules_url = $bookyourtravel_theme_globals->get_list_user_tour_schedules_url();
$list_user_cruises_url = $bookyourtravel_theme_globals->get_list_user_cruises_url();
$list_user_cruise_schedules_url = $bookyourtravel_theme_globals->get_list_user_cruise_schedules_url();
$list_user_cabin_types_url = $bookyourtravel_theme_globals->get_list_user_cabin_types_url();
$list_user_car_rentals_url = $bookyourtravel_theme_globals->get_list_user_car_rentals_url();

if (empty($my_account_page_url) &&
	empty($submit_room_types_url) &&
	empty($submit_accommodations_url) &&
	empty($submit_accommodation_vacancies_url) &&
	empty($submit_tours_url) &&
	empty($submit_tour_schedules_url) &&	
	empty($submit_cruises_url) &&
	empty($submit_cabin_types_url) &&
	empty($submit_cruise_schedules_url) &&		
	empty($submit_car_rentals_url) &&
	empty($list_user_room_types_url) &&
	empty($list_user_accommodations_url) &&
	empty($list_user_accommodation_vacancies_url) &&
	empty($list_user_tours_url) &&
	empty($list_user_tour_schedules_url) &&
	empty($list_user_cruises_url) &&
	empty($list_user_cabin_types_url) &&
	empty($list_user_cruise_schedules_url) &&
	empty($list_user_car_rentals_url)) {
	echo "<p class='error'>" . esc_html__('You have not configured Page Settings in Theme Options to get full functionality of this page. Please go to Appearance -> Theme Options -> Page Settings and configure the page options.', 'bookyourtravel') . "</p>";
}

global $post;
$page_id = $post->ID;
$page_custom_fields = get_post_custom( $page_id );
$current_url = get_permalink( $page_id );

$content_type = 'accommodation';
if (isset($page_custom_fields['frontend_submit_content_type'])) {
	$content_type = $page_custom_fields['frontend_submit_content_type'][0];
	$frontend_submit->prepare_form($content_type);
}

$login_page_url = $bookyourtravel_theme_globals->get_login_page_url();
$register_page_url = $bookyourtravel_theme_globals->get_register_page_url();
$my_account_page_url = $bookyourtravel_theme_globals->get_my_account_page_url();

$page_sidebar_positioning = null;
if (isset($page_custom_fields['page_sidebar_positioning'])) {
	$page_sidebar_positioning = $page_custom_fields['page_sidebar_positioning'][0];
	$page_sidebar_positioning = empty($page_sidebar_positioning) ? '' : $page_sidebar_positioning;
}

$section_class = 'full-width';
if ($page_sidebar_positioning == 'both')
	$section_class = 'one-half';
else if ($page_sidebar_positioning == 'left' || $page_sidebar_positioning == 'right') 
	$section_class = 'three-fourth';
?>
<div class="row">
	<?php	
	if ($page_sidebar_positioning == 'both' || $page_sidebar_positioning == 'left')
		get_sidebar('left');
		
	$allowed_tags = array();
	$allowed_tags['span'] = array('class' => array());
	?>
	<section class="<?php echo esc_attr($section_class); ?>">
		<nav class="inner-nav">
			<ul>
				<?php if (!empty($my_account_page_url)) { ?>
				<li <?php echo $current_url == $my_account_page_url ? 'class="active"' : ''; ?>><a href="<?php echo esc_url($my_account_page_url); ?>" title="<?php esc_attr_e('Settings', 'bookyourtravel'); ?>"><?php esc_html_e('Settings', 'bookyourtravel'); ?></a></li>
				<?php } ?>
				<?php if ($frontend_submit->user_has_correct_role()) { ?>
				<?php 	if ($enable_accommodations) { ?>
				<?php 		if (!empty($list_user_room_types_url)) { ?>
				<li <?php echo $current_url == $list_user_room_types_url ? 'class="active"' : ''; ?>><a href="<?php echo esc_url($list_user_room_types_url); ?>" title="<?php esc_attr_e('My Room Types', 'bookyourtravel'); ?>"><?php esc_html_e('My Room Types', 'bookyourtravel'); ?></a></li>
				<?php 		} ?>
				<?php 		if (!empty($list_user_accommodations_url)) { ?>
				<li <?php echo $current_url == $list_user_accommodations_url ? 'class="active"' : ''; ?>><a href="<?php echo esc_url($list_user_accommodations_url); ?>" title="<?php esc_attr_e('My Accommodations', 'bookyourtravel'); ?>"><?php esc_html_e('My Accommodations', 'bookyourtravel'); ?></a></li>
				<?php 		} ?>
				<?php 		if (!empty($list_user_accommodation_vacancies_url)) { ?>
				<li <?php echo $current_url == $list_user_accommodation_vacancies_url ? 'class="active"' : ''; ?>><a href="<?php echo esc_url($list_user_accommodation_vacancies_url); ?>" title="<?php esc_attr_e('My Vacancies', 'bookyourtravel'); ?>"><?php esc_html_e('My Vacancies', 'bookyourtravel'); ?></a></li>
				<?php 		} ?>
				<?php 	} ?>				
				<?php 	if ($enable_tours) { ?>				
				<?php 		if (!empty($list_user_tours_url)) { ?>
				<li <?php echo $current_url == $list_user_tours_url ? 'class="active"' : ''; ?>><a href="<?php echo esc_url($list_user_tours_url); ?>" title="<?php esc_attr_e('My Tours', 'bookyourtravel'); ?>"><?php esc_html_e('My Tours', 'bookyourtravel'); ?></a></li>
				<?php 		} ?>
				<?php 		if (!empty($list_user_tour_schedules_url)) { ?>
				<li <?php echo $current_url == $list_user_tour_schedules_url ? 'class="active"' : ''; ?>><a href="<?php echo esc_url($list_user_tour_schedules_url); ?>" title="<?php esc_attr_e('My Tour Schedules', 'bookyourtravel'); ?>"><?php esc_html_e('My Tour Schedules', 'bookyourtravel'); ?></a></li>
				<?php 		} ?>
				<?php 	} ?>				
				<?php 	if ($enable_cruises) { ?>								
				<?php 		if (!empty($list_user_cruises_url)) { ?>
				<li <?php echo $current_url == $list_user_cruises_url ? 'class="active"' : ''; ?>><a href="<?php echo esc_url($list_user_cruises_url); ?>" title="<?php esc_attr_e('My Cruises', 'bookyourtravel'); ?>"><?php esc_html_e('My Cruises', 'bookyourtravel'); ?></a></li>
				<?php 		} ?>
				<?php 		if (!empty($list_user_cabin_types_url)) { ?>
				<li <?php echo $current_url == $list_user_cabin_types_url ? 'class="active"' : ''; ?>><a href="<?php echo esc_url($list_user_cabin_types_url); ?>" title="<?php esc_attr_e('My Cabin Types', 'bookyourtravel'); ?>"><?php esc_html_e('My Cabin Types', 'bookyourtravel'); ?></a></li>
				<?php 		} ?>
				<?php 		if (!empty($list_user_cruise_schedules_url)) { ?>
				<li <?php echo $current_url == $list_user_cruise_schedules_url ? 'class="active"' : ''; ?>><a href="<?php echo esc_url($list_user_cruise_schedules_url); ?>" title="<?php esc_attr_e('My Cruise Schedules', 'bookyourtravel'); ?>"><?php esc_html_e('My Cruise Schedules', 'bookyourtravel'); ?></a></li>
				<?php 		} ?>
				<?php 	} ?>				
				<?php 	if ($enable_car_rentals) { ?>	
				<?php 		if (!empty($list_user_car_rentals_url)) { ?>
				<li <?php echo $current_url == $list_user_car_rentals_url ? 'class="active"' : ''; ?>><a href="<?php echo esc_url($list_user_car_rentals_url); ?>" title="<?php esc_attr_e('My Car Rentals', 'bookyourtravel'); ?>"><?php esc_html_e('My Car Rentals', 'bookyourtravel'); ?></a></li>
				<?php 		} ?>
				<?php 	} ?>				
				<?php 	if ($enable_accommodations) { ?>					
				<?php 		if (!empty($submit_room_types_url)) { ?>
				<li <?php echo $current_url == $submit_room_types_url ? 'class="active"' : ''; ?>><a href="<?php echo esc_url($submit_room_types_url); ?>" title="<?php esc_attr_e('Submit Room Type', 'bookyourtravel'); ?>"><?php esc_html_e('Submit Room Types', 'bookyourtravel'); ?></a></li>
				<?php 		} ?>
				<?php 		if (!empty($submit_accommodations_url)) { ?>
				<li <?php echo $current_url == $submit_accommodations_url ? 'class="active"' : ''; ?>><a href="<?php echo esc_url($submit_accommodations_url); ?>" title="<?php esc_attr_e('Submit Accommodation', 'bookyourtravel'); ?>"><?php esc_html_e('Submit Accommodations', 'bookyourtravel'); ?></a></li>
				<?php 		} ?>
				<?php 		if (!empty($submit_accommodation_vacancies_url)) { ?>
				<li <?php echo $current_url == $submit_accommodation_vacancies_url ? 'class="active"' : ''; ?>><a href="<?php echo esc_url($submit_accommodation_vacancies_url); ?>" title="<?php esc_attr_e('Submit Vacancy', 'bookyourtravel'); ?>"><?php esc_html_e('Submit Vacancies', 'bookyourtravel'); ?></a></li>
				<?php 		} ?>
				<?php 	} ?>				
				<?php 	if ($enable_tours) { ?>					
				<?php 		if (!empty($submit_tours_url)) { ?>
				<li <?php echo $current_url == $submit_tours_url ? 'class="active"' : ''; ?>><a href="<?php echo esc_url($submit_tours_url); ?>" title="<?php esc_attr_e('Submit Tour', 'bookyourtravel'); ?>"><?php esc_html_e('Submit Tour', 'bookyourtravel'); ?></a></li>
				<?php 		} ?>
				<?php 		if (!empty($submit_tour_schedules_url)) { ?>
				<li <?php echo $current_url == $submit_tour_schedules_url ? 'class="active"' : ''; ?>><a href="<?php echo esc_url($submit_tour_schedules_url); ?>" title="<?php esc_attr_e('Submit Tour Schedules', 'bookyourtravel'); ?>"><?php esc_html_e('Submit Tour Schedules', 'bookyourtravel'); ?></a></li>
				<?php 		} ?>
				<?php 	} ?>				
				<?php 	if ($enable_cruises) { ?>					
				<?php 		if (!empty($submit_cruises_url)) { ?>
				<li <?php echo $current_url == $submit_cruises_url ? 'class="active"' : ''; ?>><a href="<?php echo esc_url($submit_cruises_url); ?>" title="<?php esc_attr_e('Submit Cruise', 'bookyourtravel'); ?>"><?php esc_html_e('Submit Cruise', 'bookyourtravel'); ?></a></li>
				<?php 		} ?>
				<?php 		if (!empty($submit_cabin_types_url)) { ?>
				<li <?php echo $current_url == $submit_cabin_types_url ? 'class="active"' : ''; ?>><a href="<?php echo esc_url($submit_cabin_types_url); ?>" title="<?php esc_attr_e('Submit Cabin Type', 'bookyourtravel'); ?>"><?php esc_html_e('Submit Cabin Type', 'bookyourtravel'); ?></a></li>
				<?php 		} ?>
				<?php 		if (!empty($submit_cruise_schedules_url)) { ?>
				<li <?php echo $current_url == $submit_cruise_schedules_url ? 'class="active"' : ''; ?>><a href="<?php echo esc_url($submit_cruise_schedules_url); ?>" title="<?php esc_attr_e('Submit Cruise Schedules', 'bookyourtravel'); ?>"><?php esc_html_e('Submit Cruise Schedules', 'bookyourtravel'); ?></a></li>
				<?php 		} ?>
				<?php 	} ?>				
				<?php 	if ($enable_car_rentals) { ?>					
				<?php 		if (!empty($submit_car_rentals_url)) { ?>
				<li <?php echo $current_url == $submit_car_rentals_url ? 'class="active"' : ''; ?>><a href="<?php echo esc_url($submit_car_rentals_url); ?>" title="<?php esc_attr_e('Submit Car Rental', 'bookyourtravel'); ?>"><?php esc_html_e('Submit Car Rental', 'bookyourtravel'); ?></a></li>
				<?php 		} ?>
				<?php 	} ?>				
				<?php } ?>
			</ul>
		</nav>
		<!--//inner navigation-->	
		<section id="Submit" class="tab-content initial">
			<?php  while ( have_posts() ) : the_post(); ?>
			<article id="page-<?php the_ID(); ?>">
				<h2><?php the_title(); ?></h2>
				<?php the_content( wp_kses(__( 'Continue reading <span class="meta-nav">&rarr;</span>', 'bookyourtravel' ), $allowed_tags) ); ?>
				<?php wp_link_pages('before=<div class="pagination">&after=</div>'); ?>
				<?php echo $frontend_submit->render_upload_form(); ?>
			</article>		
			<?php endwhile; ?>
		</section>
	</section>
	<?php
	wp_reset_postdata();
	wp_reset_query();

	if ($page_sidebar_positioning == 'both' || $page_sidebar_positioning == 'right')
		get_sidebar('right');
	?>
</div>
<?php
get_footer();